Struct AxisScroll
pub struct AxisScroll {
pub absolute: f64,
pub discrete: i32,
pub value120: i32,
pub relative_direction: Option<AxisRelativeDirection>,
pub stop: bool,
}Available on crate feature
wayland and Linux only.Expand description
Describes a scroll along one axis
Fields
absolute: f64The scroll measured in pixels.
discrete: i32The scroll measured in steps.
Note: this might always be zero if the scrolling is due to a touchpad or other continuous source.
This event is deprecated and will be sent only by older compositors.
value120: i32High-resolution wheel scroll information, with each multiple of 120 representing one logical scroll step.
relative_direction: Option<AxisRelativeDirection>Relative directional information of the entity causing the axis motion.
stop: boolThe scroll was stopped.
Generally this is encountered when hardware indicates the end of some continuous scrolling.
Implementations
impl AxisScroll
impl AxisScroll