Trait PointerHandler
pub trait PointerHandler: Sized {
// Required method
fn pointer_frame(
&mut self,
conn: &Connection,
qh: &QueueHandle<Self>,
pointer: &WlPointer,
events: &[PointerEvent],
);
}Available on crate feature
wayland and Linux only.Required Methods
fn pointer_frame(
&mut self,
conn: &Connection,
qh: &QueueHandle<Self>,
pointer: &WlPointer,
events: &[PointerEvent],
)
fn pointer_frame( &mut self, conn: &Connection, qh: &QueueHandle<Self>, pointer: &WlPointer, events: &[PointerEvent], )
One or more pointer events are available.
Multiple related events may be grouped together in a single frame. Some examples:
- A drag that terminates outside the surface may send the Release and Leave events as one frame
- Movement from one surface to another may send the Enter and Leave events in one frame
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.